summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui
diff options
context:
space:
mode:
authorben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-16 00:13:01 +0000
committerben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-16 00:13:01 +0000
commita8add2b949474a43d9852966b98c2774af060e1e (patch)
treee50a9987226f3d32b4ec8fbc188403ca67490792 /chrome/browser/ui
parente118ff727561aa0472333ea0fef9ff3b9ed8c541 (diff)
downloadchromium_src-a8add2b949474a43d9852966b98c2774af060e1e.zip
chromium_src-a8add2b949474a43d9852966b98c2774af060e1e.tar.gz
chromium_src-a8add2b949474a43d9852966b98c2774af060e1e.tar.bz2
Rename Paint* -> OnPaint*
http://crbug.com/72040 TEST=none TBR=sky Review URL: http://codereview.chromium.org/6499030 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@75033 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui')
-rw-r--r--chrome/browser/ui/touch/tabs/touch_tab.cc2
-rw-r--r--chrome/browser/ui/touch/tabs/touch_tab.h2
-rw-r--r--chrome/browser/ui/views/about_chrome_view.cc4
-rw-r--r--chrome/browser/ui/views/about_chrome_view.h2
-rw-r--r--chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc10
-rw-r--r--chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.h4
-rw-r--r--chrome/browser/ui/views/browser_actions_container.cc2
-rw-r--r--chrome/browser/ui/views/browser_actions_container.h2
-rw-r--r--chrome/browser/ui/views/constrained_window_win.cc4
-rw-r--r--chrome/browser/ui/views/create_application_shortcut_view.cc4
-rw-r--r--chrome/browser/ui/views/default_search_view.cc2
-rw-r--r--chrome/browser/ui/views/default_search_view.h2
-rw-r--r--chrome/browser/ui/views/download_item_view.cc2
-rw-r--r--chrome/browser/ui/views/download_item_view.h2
-rw-r--r--chrome/browser/ui/views/download_shelf_view.cc8
-rw-r--r--chrome/browser/ui/views/download_shelf_view.h4
-rw-r--r--chrome/browser/ui/views/find_bar_view.cc2
-rw-r--r--chrome/browser/ui/views/find_bar_view.h2
-rw-r--r--chrome/browser/ui/views/first_run_search_engine_view.cc2
-rw-r--r--chrome/browser/ui/views/first_run_search_engine_view.h2
-rw-r--r--chrome/browser/ui/views/frame/app_panel_browser_frame_view.cc2
-rw-r--r--chrome/browser/ui/views/frame/app_panel_browser_frame_view.h2
-rw-r--r--chrome/browser/ui/views/frame/glass_browser_frame_view.cc2
-rw-r--r--chrome/browser/ui/views/frame/glass_browser_frame_view.h2
-rw-r--r--chrome/browser/ui/views/frame/opaque_browser_frame_view.cc2
-rw-r--r--chrome/browser/ui/views/frame/opaque_browser_frame_view.h2
-rw-r--r--chrome/browser/ui/views/fullscreen_exit_bubble.cc4
-rw-r--r--chrome/browser/ui/views/info_bubble.cc4
-rw-r--r--chrome/browser/ui/views/info_bubble.h2
-rw-r--r--chrome/browser/ui/views/infobars/translate_infobar_base.cc2
-rw-r--r--chrome/browser/ui/views/infobars/translate_infobar_base.h2
-rw-r--r--chrome/browser/ui/views/location_bar/content_setting_image_view.cc8
-rw-r--r--chrome/browser/ui/views/location_bar/content_setting_image_view.h4
-rw-r--r--chrome/browser/ui/views/location_bar/icon_label_bubble_view.cc2
-rw-r--r--chrome/browser/ui/views/location_bar/icon_label_bubble_view.h2
-rw-r--r--chrome/browser/ui/views/location_bar/keyword_hint_view.cc2
-rw-r--r--chrome/browser/ui/views/location_bar/keyword_hint_view.h2
-rw-r--r--chrome/browser/ui/views/location_bar/location_bar_view.cc6
-rw-r--r--chrome/browser/ui/views/location_bar/location_bar_view.h4
-rw-r--r--chrome/browser/ui/views/location_bar/suggested_text_view.cc2
-rw-r--r--chrome/browser/ui/views/location_bar/suggested_text_view.h2
-rw-r--r--chrome/browser/ui/views/notifications/balloon_view.cc6
-rw-r--r--chrome/browser/ui/views/notifications/balloon_view.h2
-rw-r--r--chrome/browser/ui/views/options/advanced_contents_view.cc4
-rw-r--r--chrome/browser/ui/views/options/fonts_page_view.cc4
-rw-r--r--chrome/browser/ui/views/options/options_group_view.cc2
-rw-r--r--chrome/browser/ui/views/options/options_group_view.h2
-rw-r--r--chrome/browser/ui/views/sad_tab_view.cc2
-rw-r--r--chrome/browser/ui/views/sad_tab_view.h2
-rw-r--r--chrome/browser/ui/views/status_bubble_views.cc4
-rw-r--r--chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc2
-rw-r--r--chrome/browser/ui/views/tab_icon_view.cc2
-rw-r--r--chrome/browser/ui/views/tab_icon_view.h4
-rw-r--r--chrome/browser/ui/views/tabs/dragged_tab_controller.cc2
-rw-r--r--chrome/browser/ui/views/tabs/dragged_tab_view.cc2
-rw-r--r--chrome/browser/ui/views/tabs/dragged_tab_view.h2
-rw-r--r--chrome/browser/ui/views/tabs/side_tab.cc2
-rw-r--r--chrome/browser/ui/views/tabs/side_tab.h2
-rw-r--r--chrome/browser/ui/views/tabs/tab.cc6
-rw-r--r--chrome/browser/ui/views/tabs/tab.h2
-rw-r--r--chrome/browser/ui/views/theme_install_bubble_view.cc2
-rw-r--r--chrome/browser/ui/views/theme_install_bubble_view.h2
-rw-r--r--chrome/browser/ui/views/toolbar_view.cc6
-rw-r--r--chrome/browser/ui/views/toolbar_view.h2
64 files changed, 95 insertions, 95 deletions
diff --git a/chrome/browser/ui/touch/tabs/touch_tab.cc b/chrome/browser/ui/touch/tabs/touch_tab.cc
index d9d8d95..69be10d 100644
--- a/chrome/browser/ui/touch/tabs/touch_tab.cc
+++ b/chrome/browser/ui/touch/tabs/touch_tab.cc
@@ -56,7 +56,7 @@ const gfx::Rect& TouchTab::GetIconBounds() const {
////////////////////////////////////////////////////////////////////////////////
// TouchTab, views::View overrides:
-void TouchTab::Paint(gfx::Canvas* canvas) {
+void TouchTab::OnPaint(gfx::Canvas* canvas) {
// Don't paint if we're narrower than we can render correctly. (This should
// only happen during animations).
if (width() < GetMinimumUnselectedSize().width() && !data().mini)
diff --git a/chrome/browser/ui/touch/tabs/touch_tab.h b/chrome/browser/ui/touch/tabs/touch_tab.h
index aa252e47..614f18e 100644
--- a/chrome/browser/ui/touch/tabs/touch_tab.h
+++ b/chrome/browser/ui/touch/tabs/touch_tab.h
@@ -43,7 +43,7 @@ class TouchTab : public BaseTab {
private:
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
virtual bool HasHitTestMask() const;
virtual void GetHitTestMask(gfx::Path* path) const;
diff --git a/chrome/browser/ui/views/about_chrome_view.cc b/chrome/browser/ui/views/about_chrome_view.cc
index e68ce75..4b2cf5a 100644
--- a/chrome/browser/ui/views/about_chrome_view.cc
+++ b/chrome/browser/ui/views/about_chrome_view.cc
@@ -429,8 +429,8 @@ void AboutChromeView::Layout() {
}
-void AboutChromeView::Paint(gfx::Canvas* canvas) {
- views::View::Paint(canvas);
+void AboutChromeView::OnPaint(gfx::Canvas* canvas) {
+ views::View::OnPaint(canvas);
// Draw the background image color (and the separator) across the dialog.
// This will become the background for the logo image at the top of the
diff --git a/chrome/browser/ui/views/about_chrome_view.h b/chrome/browser/ui/views/about_chrome_view.h
index edbcb32..6393de0 100644
--- a/chrome/browser/ui/views/about_chrome_view.h
+++ b/chrome/browser/ui/views/about_chrome_view.h
@@ -51,7 +51,7 @@ class AboutChromeView : public views::View,
// Overridden from views::View:
virtual gfx::Size GetPreferredSize();
virtual void Layout();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void ViewHierarchyChanged(bool is_add,
views::View* parent,
views::View* child);
diff --git a/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc b/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc
index e507df5..65e6c3b 100644
--- a/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc
+++ b/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc
@@ -233,7 +233,7 @@ class AutocompletePopupContentsView::InstantOptInView
// WARNING: we've been deleted.
}
- virtual void Paint(gfx::Canvas* canvas) {
+ virtual void OnPaint(gfx::Canvas* canvas) {
canvas->Save();
canvas->TranslateInt(kOptInBackgroundHInset, kOptInBackgroundVInset);
bg_painter_->Paint(width() - kOptInBackgroundHInset * 2,
@@ -281,7 +281,7 @@ class AutocompleteResultView : public views::View {
void set_match(const AutocompleteMatch& match) { match_ = match; }
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
virtual gfx::Size GetPreferredSize();
@@ -436,7 +436,7 @@ AutocompleteResultView::AutocompleteResultView(
AutocompleteResultView::~AutocompleteResultView() {
}
-void AutocompleteResultView::Paint(gfx::Canvas* canvas) {
+void AutocompleteResultView::OnPaint(gfx::Canvas* canvas) {
const ResultViewState state = GetState();
if (state != NORMAL)
canvas->AsCanvasSkia()->drawColor(GetColor(state, BACKGROUND));
@@ -945,7 +945,7 @@ void AutocompletePopupContentsView::AnimationProgressed(
////////////////////////////////////////////////////////////////////////////////
// AutocompletePopupContentsView, views::View overrides:
-void AutocompletePopupContentsView::Paint(gfx::Canvas* canvas) {
+void AutocompletePopupContentsView::OnPaint(gfx::Canvas* canvas) {
// We paint our children in an unconventional way.
//
// Because the border of this view creates an anti-aliased round-rect region
@@ -983,7 +983,7 @@ void AutocompletePopupContentsView::Paint(gfx::Canvas* canvas) {
// Now we paint the border, so it will be alpha-blended atop the contents.
// This looks slightly better in the corners than drawing the contents atop
// the border.
- PaintBorder(canvas);
+ OnPaintBorder(canvas);
}
void AutocompletePopupContentsView::Layout() {
diff --git a/chrome/browser/ui/views/browser_actions_container.cc b/chrome/browser/ui/views/browser_actions_container.cc
index 9516d73..c405253 100644
--- a/chrome/browser/ui/views/browser_actions_container.cc
+++ b/chrome/browser/ui/views/browser_actions_container.cc
@@ -575,7 +575,7 @@ void BrowserActionsContainer::Layout() {
}
}
-void BrowserActionsContainer::Paint(gfx::Canvas* canvas) {
+void BrowserActionsContainer::OnPaint(gfx::Canvas* canvas) {
// TODO(sky/glen): Instead of using a drop indicator, animate the icons while
// dragging (like we do for tab dragging).
if (drop_indicator_position_ > -1) {
diff --git a/chrome/browser/ui/views/browser_actions_container.h b/chrome/browser/ui/views/browser_actions_container.h
index 4bce4b5..94c13139e 100644
--- a/chrome/browser/ui/views/browser_actions_container.h
+++ b/chrome/browser/ui/views/browser_actions_container.h
@@ -318,7 +318,7 @@ class BrowserActionsContainer
// Overridden from views::View:
virtual gfx::Size GetPreferredSize();
virtual void Layout();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void ViewHierarchyChanged(bool is_add,
views::View* parent,
views::View* child);
diff --git a/chrome/browser/ui/views/constrained_window_win.cc b/chrome/browser/ui/views/constrained_window_win.cc
index 5827e52..01e2a58 100644
--- a/chrome/browser/ui/views/constrained_window_win.cc
+++ b/chrome/browser/ui/views/constrained_window_win.cc
@@ -158,7 +158,7 @@ class ConstrainedWindowFrameView
virtual void ResetWindowControls() { }
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
virtual void OnThemeChanged();
@@ -344,7 +344,7 @@ void ConstrainedWindowFrameView::EnableClose(bool enable) {
////////////////////////////////////////////////////////////////////////////////
// ConstrainedWindowFrameView, views::View implementation:
-void ConstrainedWindowFrameView::Paint(gfx::Canvas* canvas) {
+void ConstrainedWindowFrameView::OnPaint(gfx::Canvas* canvas) {
PaintFrameBorder(canvas);
PaintTitleBar(canvas);
PaintClientEdge(canvas);
diff --git a/chrome/browser/ui/views/create_application_shortcut_view.cc b/chrome/browser/ui/views/create_application_shortcut_view.cc
index cc12d2c..b4e59ca 100644
--- a/chrome/browser/ui/views/create_application_shortcut_view.cc
+++ b/chrome/browser/ui/views/create_application_shortcut_view.cc
@@ -50,7 +50,7 @@ class AppInfoView : public views::View {
void UpdateIcon(const SkBitmap& new_icon);
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
private:
// Initializes the controls
@@ -155,7 +155,7 @@ void AppInfoView::UpdateIcon(const SkBitmap& new_icon) {
icon_->SetImage(new_icon);
}
-void AppInfoView::Paint(gfx::Canvas* canvas) {
+void AppInfoView::OnPaint(gfx::Canvas* canvas) {
gfx::Rect bounds = GetLocalBounds();
SkRect border_rect = {
diff --git a/chrome/browser/ui/views/default_search_view.cc b/chrome/browser/ui/views/default_search_view.cc
index 3dea858..2bc8967 100644
--- a/chrome/browser/ui/views/default_search_view.cc
+++ b/chrome/browser/ui/views/default_search_view.cc
@@ -124,7 +124,7 @@ void DefaultSearchView::Show(TabContents* tab_contents,
DefaultSearchView::~DefaultSearchView() {
}
-void DefaultSearchView::Paint(gfx::Canvas* canvas) {
+void DefaultSearchView::OnPaint(gfx::Canvas* canvas) {
// Fill in behind the background image with the standard gray toolbar color.
canvas->FillRectInt(SkColorSetRGB(237, 238, 237), 0, 0, width(),
background_image_->height());
diff --git a/chrome/browser/ui/views/default_search_view.h b/chrome/browser/ui/views/default_search_view.h
index a60263e..1b07bda 100644
--- a/chrome/browser/ui/views/default_search_view.h
+++ b/chrome/browser/ui/views/default_search_view.h
@@ -49,7 +49,7 @@ class DefaultSearchView
protected:
// Overridden from views::View:
// Draws the gray background at the top of the dialog.
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
// Overridden from views::ButtonListener:
virtual void ButtonPressed(views::Button* sender, const views::Event& event);
diff --git a/chrome/browser/ui/views/download_item_view.cc b/chrome/browser/ui/views/download_item_view.cc
index 92f5c341..8736136 100644
--- a/chrome/browser/ui/views/download_item_view.cc
+++ b/chrome/browser/ui/views/download_item_view.cc
@@ -452,7 +452,7 @@ void DownloadItemView::ButtonPressed(
// Load an icon for the file type we're downloading, and animate any in progress
// download state.
-void DownloadItemView::Paint(gfx::Canvas* canvas) {
+void DownloadItemView::OnPaint(gfx::Canvas* canvas) {
BodyImageSet* body_image_set = NULL;
switch (body_state_) {
case NORMAL:
diff --git a/chrome/browser/ui/views/download_item_view.h b/chrome/browser/ui/views/download_item_view.h
index 2bdfafd..168cc25 100644
--- a/chrome/browser/ui/views/download_item_view.h
+++ b/chrome/browser/ui/views/download_item_view.h
@@ -64,7 +64,7 @@ class DownloadItemView : public views::ButtonListener,
// View overrides
virtual void Layout();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual gfx::Size GetPreferredSize();
virtual void OnMouseExited(const views::MouseEvent& event);
virtual void OnMouseMoved(const views::MouseEvent& event);
diff --git a/chrome/browser/ui/views/download_shelf_view.cc b/chrome/browser/ui/views/download_shelf_view.cc
index 1db8bd2..cc6661b 100644
--- a/chrome/browser/ui/views/download_shelf_view.cc
+++ b/chrome/browser/ui/views/download_shelf_view.cc
@@ -183,9 +183,9 @@ views::View* DownloadShelfView::GetDefaultFocusableChild() {
return show_all_view_;
}
-void DownloadShelfView::Paint(gfx::Canvas* canvas) {
- PaintBackground(canvas);
- PaintBorder(canvas);
+void DownloadShelfView::OnPaint(gfx::Canvas* canvas) {
+ OnPaintBackground(canvas);
+ OnPaintBorder(canvas);
// Draw the focus rect here, since it's outside the bounds of the item.
for (size_t i = 0; i < download_views_.size(); ++i) {
@@ -197,7 +197,7 @@ void DownloadShelfView::Paint(gfx::Canvas* canvas) {
}
}
-void DownloadShelfView::PaintBorder(gfx::Canvas* canvas) {
+void DownloadShelfView::OnPaintBorder(gfx::Canvas* canvas) {
canvas->FillRectInt(kBorderColor, 0, 0, width(), 1);
}
diff --git a/chrome/browser/ui/views/download_shelf_view.h b/chrome/browser/ui/views/download_shelf_view.h
index 8d9c1f0..10f65fa 100644
--- a/chrome/browser/ui/views/download_shelf_view.h
+++ b/chrome/browser/ui/views/download_shelf_view.h
@@ -49,7 +49,7 @@ class DownloadShelfView : public AccessiblePaneView,
// Implementation of View.
virtual gfx::Size GetPreferredSize();
virtual void Layout();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
// Implementation of ui::AnimationDelegate.
virtual void AnimationProgressed(const ui::Animation* animation);
@@ -96,7 +96,7 @@ class DownloadShelfView : public AccessiblePaneView,
void AddDownloadView(DownloadItemView* view);
// Paints the border.
- void PaintBorder(gfx::Canvas* canvas);
+ void OnPaintBorder(gfx::Canvas* canvas);
// Returns true if the shelf is wide enough to show the first download item.
bool CanFitFirstDownloadItem();
diff --git a/chrome/browser/ui/views/find_bar_view.cc b/chrome/browser/ui/views/find_bar_view.cc
index 87a7abd..52e7f53 100644
--- a/chrome/browser/ui/views/find_bar_view.cc
+++ b/chrome/browser/ui/views/find_bar_view.cc
@@ -268,7 +268,7 @@ void FindBarView::SetFocusAndSelection(bool select_all) {
///////////////////////////////////////////////////////////////////////////////
// FindBarView, views::View overrides:
-void FindBarView::Paint(gfx::Canvas* canvas) {
+void FindBarView::OnPaint(gfx::Canvas* canvas) {
SkPaint paint;
// Determine the find bar size as well as the offset from which to tile the
diff --git a/chrome/browser/ui/views/find_bar_view.h b/chrome/browser/ui/views/find_bar_view.h
index 80e7647..646f138 100644
--- a/chrome/browser/ui/views/find_bar_view.h
+++ b/chrome/browser/ui/views/find_bar_view.h
@@ -65,7 +65,7 @@ class FindBarView : public DropdownBarView,
virtual void SetFocusAndSelection(bool select_all);
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
virtual gfx::Size GetPreferredSize();
virtual void ViewHierarchyChanged(bool is_add,
diff --git a/chrome/browser/ui/views/first_run_search_engine_view.cc b/chrome/browser/ui/views/first_run_search_engine_view.cc
index 5cf2451..b1bcecf 100644
--- a/chrome/browser/ui/views/first_run_search_engine_view.cc
+++ b/chrome/browser/ui/views/first_run_search_engine_view.cc
@@ -155,7 +155,7 @@ void FirstRunSearchEngineView::ButtonPressed(views::Button* sender,
MessageLoop::current()->Quit();
}
-void FirstRunSearchEngineView::Paint(gfx::Canvas* canvas) {
+void FirstRunSearchEngineView::OnPaint(gfx::Canvas* canvas) {
// Fill in behind the background image with the standard gray toolbar color.
canvas->FillRectInt(SkColorSetRGB(237, 238, 237), 0, 0, width(),
background_image_->height());
diff --git a/chrome/browser/ui/views/first_run_search_engine_view.h b/chrome/browser/ui/views/first_run_search_engine_view.h
index 754111f..5db011b 100644
--- a/chrome/browser/ui/views/first_run_search_engine_view.h
+++ b/chrome/browser/ui/views/first_run_search_engine_view.h
@@ -105,7 +105,7 @@ class FirstRunSearchEngineView
virtual void ButtonPressed(views::Button* sender, const views::Event& event);
// Override from View so we can draw the gray background at dialog top.
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
// Overridden from TemplateURLModelObserver. When the search engines have
// loaded from the profile, we can populate the logos in the dialog box
diff --git a/chrome/browser/ui/views/frame/app_panel_browser_frame_view.cc b/chrome/browser/ui/views/frame/app_panel_browser_frame_view.cc
index bb75ed8..8ff262a 100644
--- a/chrome/browser/ui/views/frame/app_panel_browser_frame_view.cc
+++ b/chrome/browser/ui/views/frame/app_panel_browser_frame_view.cc
@@ -213,7 +213,7 @@ void AppPanelBrowserFrameView::ResetWindowControls() {
///////////////////////////////////////////////////////////////////////////////
// AppPanelBrowserFrameView, views::View overrides:
-void AppPanelBrowserFrameView::Paint(gfx::Canvas* canvas) {
+void AppPanelBrowserFrameView::OnPaint(gfx::Canvas* canvas) {
views::Window* window = frame_->GetWindow();
if (window->IsMaximized())
PaintMaximizedFrameBorder(canvas);
diff --git a/chrome/browser/ui/views/frame/app_panel_browser_frame_view.h b/chrome/browser/ui/views/frame/app_panel_browser_frame_view.h
index 198284f..b1ba9a2 100644
--- a/chrome/browser/ui/views/frame/app_panel_browser_frame_view.h
+++ b/chrome/browser/ui/views/frame/app_panel_browser_frame_view.h
@@ -51,7 +51,7 @@ class AppPanelBrowserFrameView : public BrowserNonClientFrameView,
virtual void ResetWindowControls();
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
// Overridden from views::ButtonListener:
diff --git a/chrome/browser/ui/views/frame/glass_browser_frame_view.cc b/chrome/browser/ui/views/frame/glass_browser_frame_view.cc
index 1901ae7..c52ba7c 100644
--- a/chrome/browser/ui/views/frame/glass_browser_frame_view.cc
+++ b/chrome/browser/ui/views/frame/glass_browser_frame_view.cc
@@ -192,7 +192,7 @@ int GlassBrowserFrameView::NonClientHitTest(const gfx::Point& point) {
///////////////////////////////////////////////////////////////////////////////
// GlassBrowserFrameView, views::View overrides:
-void GlassBrowserFrameView::Paint(gfx::Canvas* canvas) {
+void GlassBrowserFrameView::OnPaint(gfx::Canvas* canvas) {
if (!browser_view_->IsTabStripVisible())
return; // Nothing is visible, so don't bother to paint.
diff --git a/chrome/browser/ui/views/frame/glass_browser_frame_view.h b/chrome/browser/ui/views/frame/glass_browser_frame_view.h
index 4086ea2..331071e 100644
--- a/chrome/browser/ui/views/frame/glass_browser_frame_view.h
+++ b/chrome/browser/ui/views/frame/glass_browser_frame_view.h
@@ -37,7 +37,7 @@ class GlassBrowserFrameView : public BrowserNonClientFrameView {
protected:
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
private:
diff --git a/chrome/browser/ui/views/frame/opaque_browser_frame_view.cc b/chrome/browser/ui/views/frame/opaque_browser_frame_view.cc
index c6e7f34..878c636 100644
--- a/chrome/browser/ui/views/frame/opaque_browser_frame_view.cc
+++ b/chrome/browser/ui/views/frame/opaque_browser_frame_view.cc
@@ -349,7 +349,7 @@ void OpaqueBrowserFrameView::ResetWindowControls() {
///////////////////////////////////////////////////////////////////////////////
// OpaqueBrowserFrameView, views::View overrides:
-void OpaqueBrowserFrameView::Paint(gfx::Canvas* canvas) {
+void OpaqueBrowserFrameView::OnPaint(gfx::Canvas* canvas) {
views::Window* window = frame_->GetWindow();
if (window->IsFullscreen())
return; // Nothing is visible, so don't bother to paint.
diff --git a/chrome/browser/ui/views/frame/opaque_browser_frame_view.h b/chrome/browser/ui/views/frame/opaque_browser_frame_view.h
index baedea7..0303d3a 100644
--- a/chrome/browser/ui/views/frame/opaque_browser_frame_view.h
+++ b/chrome/browser/ui/views/frame/opaque_browser_frame_view.h
@@ -56,7 +56,7 @@ class OpaqueBrowserFrameView : public BrowserNonClientFrameView,
virtual void ResetWindowControls();
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
virtual bool HitTest(const gfx::Point& l) const;
virtual AccessibilityTypes::Role GetAccessibleRole();
diff --git a/chrome/browser/ui/views/fullscreen_exit_bubble.cc b/chrome/browser/ui/views/fullscreen_exit_bubble.cc
index fc38f30..fa85636 100644
--- a/chrome/browser/ui/views/fullscreen_exit_bubble.cc
+++ b/chrome/browser/ui/views/fullscreen_exit_bubble.cc
@@ -39,7 +39,7 @@ class FullscreenExitBubble::FullscreenExitView : public views::View {
// views::View
virtual void Layout();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
// Clickable hint text to show in the bubble.
views::Link link_;
@@ -83,7 +83,7 @@ void FullscreenExitBubble::FullscreenExitView::Layout() {
link_preferred_size.width(), link_preferred_size.height());
}
-void FullscreenExitBubble::FullscreenExitView::Paint(gfx::Canvas* canvas) {
+void FullscreenExitBubble::FullscreenExitView::OnPaint(gfx::Canvas* canvas) {
// Create a round-bottomed rect to fill the whole View.
SkRect rect;
SkScalar padding = SkIntToScalar(kPaddingPixels);
diff --git a/chrome/browser/ui/views/info_bubble.cc b/chrome/browser/ui/views/info_bubble.cc
index aad0b38..9440a9f 100644
--- a/chrome/browser/ui/views/info_bubble.cc
+++ b/chrome/browser/ui/views/info_bubble.cc
@@ -103,7 +103,7 @@ gfx::Rect BorderContents::GetMonitorBounds(const gfx::Rect& rect) {
return monitor_provider->GetMonitorWorkAreaMatching(rect);
}
-void BorderContents::Paint(gfx::Canvas* canvas) {
+void BorderContents::OnPaint(gfx::Canvas* canvas) {
// The border of this view creates an anti-aliased round-rect region for the
// contents, which we need to fill with the background color.
// NOTE: This doesn't handle an arrow location of "NONE", which has square top
@@ -124,7 +124,7 @@ void BorderContents::Paint(gfx::Canvas* canvas) {
// Now we paint the border, so it will be alpha-blended atop the contents.
// This looks slightly better in the corners than drawing the contents atop
// the border.
- PaintBorder(canvas);
+ OnPaintBorder(canvas);
}
void BorderContents::MirrorArrowIfOffScreen(
diff --git a/chrome/browser/ui/views/info_bubble.h b/chrome/browser/ui/views/info_bubble.h
index b329e80..e57ebc8 100644
--- a/chrome/browser/ui/views/info_bubble.h
+++ b/chrome/browser/ui/views/info_bubble.h
@@ -84,7 +84,7 @@ class BorderContents : public views::View {
private:
// Overridden from View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
// Changes |arrow_location| to its mirrored version, vertically if |vertical|
// is true, horizontally otherwise, if |window_bounds| don't fit in
diff --git a/chrome/browser/ui/views/infobars/translate_infobar_base.cc b/chrome/browser/ui/views/infobars/translate_infobar_base.cc
index 53c0734..83e0d81 100644
--- a/chrome/browser/ui/views/infobars/translate_infobar_base.cc
+++ b/chrome/browser/ui/views/infobars/translate_infobar_base.cc
@@ -137,7 +137,7 @@ TranslateInfoBarDelegate* TranslateInfoBarBase::GetDelegate() {
return delegate()->AsTranslateInfoBarDelegate();
}
-void TranslateInfoBarBase::PaintBackground(gfx::Canvas* canvas) {
+void TranslateInfoBarBase::OnPaintBackground(gfx::Canvas* canvas) {
// If we're not animating, simply paint the background for the current state.
if (!background_color_animation_->is_animating()) {
GetBackground().Paint(canvas, this);
diff --git a/chrome/browser/ui/views/infobars/translate_infobar_base.h b/chrome/browser/ui/views/infobars/translate_infobar_base.h
index 73494ef..35ed3aa 100644
--- a/chrome/browser/ui/views/infobars/translate_infobar_base.h
+++ b/chrome/browser/ui/views/infobars/translate_infobar_base.h
@@ -55,7 +55,7 @@ class TranslateInfoBarBase : public TranslateInfoBarView,
private:
// InfoBarView:
- virtual void PaintBackground(gfx::Canvas* canvas);
+ virtual void OnPaintBackground(gfx::Canvas* canvas);
virtual void AnimationProgressed(const ui::Animation* animation);
// Returns the background that should be displayed when not animating.
diff --git a/chrome/browser/ui/views/location_bar/content_setting_image_view.cc b/chrome/browser/ui/views/location_bar/content_setting_image_view.cc
index c7ac5d1..66ddcda 100644
--- a/chrome/browser/ui/views/location_bar/content_setting_image_view.cc
+++ b/chrome/browser/ui/views/location_bar/content_setting_image_view.cc
@@ -157,7 +157,7 @@ void ContentSettingImageView::VisibilityChanged(View* starting_from,
info_bubble_->Close();
}
-void ContentSettingImageView::Paint(gfx::Canvas* canvas) {
+void ContentSettingImageView::OnPaint(gfx::Canvas* canvas) {
gfx::Insets current_insets;
if (border())
border()->GetInsets(&current_insets);
@@ -179,7 +179,7 @@ void ContentSettingImageView::Paint(gfx::Canvas* canvas) {
set_border(empty_border);
}
// Paint an icon with possibly non-empty left border.
- views::ImageView::Paint(canvas);
+ views::ImageView::OnPaint(canvas);
if (animation_in_progress_) {
// Paint text to the right of the icon.
ResourceBundle& rb = ResourceBundle::GetSharedInstance();
@@ -191,9 +191,9 @@ void ContentSettingImageView::Paint(gfx::Canvas* canvas) {
}
}
-void ContentSettingImageView::PaintBackground(gfx::Canvas* canvas) {
+void ContentSettingImageView::OnPaintBackground(gfx::Canvas* canvas) {
if (!animation_in_progress_) {
- views::ImageView::PaintBackground(canvas);
+ views::ImageView::OnPaintBackground(canvas);
return;
}
// Paint yellow gradient background if in animation mode.
diff --git a/chrome/browser/ui/views/location_bar/content_setting_image_view.h b/chrome/browser/ui/views/location_bar/content_setting_image_view.h
index 0de0c8f..5e876fd 100644
--- a/chrome/browser/ui/views/location_bar/content_setting_image_view.h
+++ b/chrome/browser/ui/views/location_bar/content_setting_image_view.h
@@ -45,8 +45,8 @@ class ContentSettingImageView : public views::ImageView,
virtual bool OnMousePressed(const views::MouseEvent& event);
virtual void OnMouseReleased(const views::MouseEvent& event, bool canceled);
virtual void VisibilityChanged(View* starting_from, bool is_visible);
- virtual void Paint(gfx::Canvas* canvas);
- virtual void PaintBackground(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
+ virtual void OnPaintBackground(gfx::Canvas* canvas);
// InfoBubbleDelegate overrides:
virtual void InfoBubbleClosing(InfoBubble* info_bubble,
diff --git a/chrome/browser/ui/views/location_bar/icon_label_bubble_view.cc b/chrome/browser/ui/views/location_bar/icon_label_bubble_view.cc
index c4a61ef..7640e96 100644
--- a/chrome/browser/ui/views/location_bar/icon_label_bubble_view.cc
+++ b/chrome/browser/ui/views/location_bar/icon_label_bubble_view.cc
@@ -46,7 +46,7 @@ void IconLabelBubbleView::SetImage(const SkBitmap& bitmap) {
image_->SetImage(bitmap);
}
-void IconLabelBubbleView::Paint(gfx::Canvas* canvas) {
+void IconLabelBubbleView::OnPaint(gfx::Canvas* canvas) {
background_painter_.Paint(width(), height(), canvas);
}
diff --git a/chrome/browser/ui/views/location_bar/icon_label_bubble_view.h b/chrome/browser/ui/views/location_bar/icon_label_bubble_view.h
index 97b4546..c60e872 100644
--- a/chrome/browser/ui/views/location_bar/icon_label_bubble_view.h
+++ b/chrome/browser/ui/views/location_bar/icon_label_bubble_view.h
@@ -38,7 +38,7 @@ class IconLabelBubbleView : public views::View {
void SetImage(const SkBitmap& bitmap);
void SetItemPadding(int padding) { item_padding_ = padding; }
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual gfx::Size GetPreferredSize();
virtual void Layout();
diff --git a/chrome/browser/ui/views/location_bar/keyword_hint_view.cc b/chrome/browser/ui/views/location_bar/keyword_hint_view.cc
index c2f28d1..a9da4ac 100644
--- a/chrome/browser/ui/views/location_bar/keyword_hint_view.cc
+++ b/chrome/browser/ui/views/location_bar/keyword_hint_view.cc
@@ -79,7 +79,7 @@ void KeywordHintView::SetKeyword(const string16& keyword) {
}
}
-void KeywordHintView::Paint(gfx::Canvas* canvas) {
+void KeywordHintView::OnPaint(gfx::Canvas* canvas) {
int image_x = leading_label_->IsVisible() ? leading_label_->width() : 0;
// Since we paint the button image directly on the canvas (instead of using a
diff --git a/chrome/browser/ui/views/location_bar/keyword_hint_view.h b/chrome/browser/ui/views/location_bar/keyword_hint_view.h
index 64e18a9..e0a3858 100644
--- a/chrome/browser/ui/views/location_bar/keyword_hint_view.h
+++ b/chrome/browser/ui/views/location_bar/keyword_hint_view.h
@@ -39,7 +39,7 @@ class KeywordHintView : public views::View {
void SetKeyword(const string16& keyword);
string16 keyword() const { return keyword_; }
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual gfx::Size GetPreferredSize();
// The minimum size is just big enough to show the tab.
virtual gfx::Size GetMinimumSize();
diff --git a/chrome/browser/ui/views/location_bar/location_bar_view.cc b/chrome/browser/ui/views/location_bar/location_bar_view.cc
index 08d9f9c..c19a664 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_view.cc
+++ b/chrome/browser/ui/views/location_bar/location_bar_view.cc
@@ -634,8 +634,8 @@ void LocationBarView::Layout() {
location_entry_view_->SetBoundsRect(location_bounds);
}
-void LocationBarView::Paint(gfx::Canvas* canvas) {
- View::Paint(canvas);
+void LocationBarView::OnPaint(gfx::Canvas* canvas) {
+ View::OnPaint(canvas);
if (painter_.get()) {
painter_->Paint(width(), height(), canvas);
@@ -652,7 +652,7 @@ void LocationBarView::Paint(gfx::Canvas* canvas) {
// TODO(pkasting): We need images that are transparent in the middle, so we
// can draw the border images over the background color instead of the
// reverse; this antialiases better (see comments in
- // AutocompletePopupContentsView::Paint()).
+ // AutocompletePopupContentsView::OnPaint()).
gfx::Rect bounds(GetContentsBounds());
bounds.Inset(0, kVerticalEdgeThickness);
SkColor color(GetColor(ToolbarModel::NONE, BACKGROUND));
diff --git a/chrome/browser/ui/views/location_bar/location_bar_view.h b/chrome/browser/ui/views/location_bar/location_bar_view.h
index 82445b6..424241c 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_view.h
+++ b/chrome/browser/ui/views/location_bar/location_bar_view.h
@@ -159,10 +159,10 @@ class LocationBarView : public LocationBar,
// Layout and Painting functions
virtual void Layout();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
// No focus border for the location bar, the caret is enough.
- virtual void PaintFocusBorder(gfx::Canvas* canvas) { }
+ virtual void OnPaintFocusBorder(gfx::Canvas* canvas) { }
// Called when any ancestor changes its size, asks the AutocompleteEditModel
// to close its popup.
diff --git a/chrome/browser/ui/views/location_bar/suggested_text_view.cc b/chrome/browser/ui/views/location_bar/suggested_text_view.cc
index fe7094d..d694182 100644
--- a/chrome/browser/ui/views/location_bar/suggested_text_view.cc
+++ b/chrome/browser/ui/views/location_bar/suggested_text_view.cc
@@ -37,7 +37,7 @@ void SuggestedTextView::StopAnimation() {
}
}
-void SuggestedTextView::PaintBackground(gfx::Canvas* canvas) {
+void SuggestedTextView::OnPaintBackground(gfx::Canvas* canvas) {
if (!animation_.get() || animation_->GetCurrentValue() == 0)
return;
diff --git a/chrome/browser/ui/views/location_bar/suggested_text_view.h b/chrome/browser/ui/views/location_bar/suggested_text_view.h
index 893901a..9f706b2 100644
--- a/chrome/browser/ui/views/location_bar/suggested_text_view.h
+++ b/chrome/browser/ui/views/location_bar/suggested_text_view.h
@@ -30,7 +30,7 @@ class SuggestedTextView : public views::Label,
void StopAnimation();
// View overrides:
- virtual void PaintBackground(gfx::Canvas* canvas);
+ virtual void OnPaintBackground(gfx::Canvas* canvas);
// AnimationDelegate overrides:
virtual void AnimationEnded(const ui::Animation* animation);
diff --git a/chrome/browser/ui/views/notifications/balloon_view.cc b/chrome/browser/ui/views/notifications/balloon_view.cc
index 69859cb..ccb4612 100644
--- a/chrome/browser/ui/views/notifications/balloon_view.cc
+++ b/chrome/browser/ui/views/notifications/balloon_view.cc
@@ -472,7 +472,7 @@ gfx::Rect BalloonViewImpl::GetContentsRectangle() const {
content_size.height());
}
-void BalloonViewImpl::Paint(gfx::Canvas* canvas) {
+void BalloonViewImpl::OnPaint(gfx::Canvas* canvas) {
DCHECK(canvas);
// Paint the menu bar area white, with proper rounded corners.
gfx::Path path;
@@ -490,8 +490,8 @@ void BalloonViewImpl::Paint(gfx::Canvas* canvas) {
canvas->FillRectInt(kControlBarSeparatorLineColor,
kLeftMargin, 1 + GetShelfHeight(), line_width, 1);
- View::Paint(canvas);
- PaintBorder(canvas);
+ View::OnPaint(canvas);
+ OnPaintBorder(canvas);
}
void BalloonViewImpl::Observe(NotificationType type,
diff --git a/chrome/browser/ui/views/notifications/balloon_view.h b/chrome/browser/ui/views/notifications/balloon_view.h
index 82bb309..804593a 100644
--- a/chrome/browser/ui/views/notifications/balloon_view.h
+++ b/chrome/browser/ui/views/notifications/balloon_view.h
@@ -66,7 +66,7 @@ class BalloonViewImpl : public BalloonView,
private:
// views::View interface.
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void OnBoundsChanged();
virtual gfx::Size GetPreferredSize();
diff --git a/chrome/browser/ui/views/options/advanced_contents_view.cc b/chrome/browser/ui/views/options/advanced_contents_view.cc
index 3711870..d192269 100644
--- a/chrome/browser/ui/views/options/advanced_contents_view.cc
+++ b/chrome/browser/ui/views/options/advanced_contents_view.cc
@@ -90,7 +90,7 @@ class FileDisplayArea : public views::View {
void SetFile(const FilePath& file_path);
// views::View overrides:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
virtual gfx::Size GetPreferredSize();
@@ -140,7 +140,7 @@ void FileDisplayArea::SetFile(const FilePath& file_path) {
}
}
-void FileDisplayArea::Paint(gfx::Canvas* canvas) {
+void FileDisplayArea::OnPaint(gfx::Canvas* canvas) {
HDC dc = canvas->BeginPlatformPaint();
RECT rect = { 0, 0, width(), height() };
gfx::NativeTheme::instance()->PaintTextField(
diff --git a/chrome/browser/ui/views/options/fonts_page_view.cc b/chrome/browser/ui/views/options/fonts_page_view.cc
index be6b4a7..44d6b5c 100644
--- a/chrome/browser/ui/views/options/fonts_page_view.cc
+++ b/chrome/browser/ui/views/options/fonts_page_view.cc
@@ -50,7 +50,7 @@ class FontDisplayView : public views::View {
int font_size() { return font_size_; }
// views::View overrides:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
virtual gfx::Size GetPreferredSize();
@@ -94,7 +94,7 @@ void FontDisplayView::SetFontType(const std::wstring& font_name,
font_text_label_->SetText(displayed_text);
}
-void FontDisplayView::Paint(gfx::Canvas* canvas) {
+void FontDisplayView::OnPaint(gfx::Canvas* canvas) {
HDC dc = canvas->BeginPlatformPaint();
RECT rect = { 0, 0, width(), height() };
gfx::NativeTheme::instance()->PaintTextField(
diff --git a/chrome/browser/ui/views/options/options_group_view.cc b/chrome/browser/ui/views/options/options_group_view.cc
index 0d4a64d..f4a9670 100644
--- a/chrome/browser/ui/views/options/options_group_view.cc
+++ b/chrome/browser/ui/views/options/options_group_view.cc
@@ -74,7 +74,7 @@ AccessibilityTypes::Role OptionsGroupView::GetAccessibleRole() {
return AccessibilityTypes::ROLE_GROUPING;
}
-void OptionsGroupView::Paint(gfx::Canvas* canvas) {
+void OptionsGroupView::OnPaint(gfx::Canvas* canvas) {
if (highlighted_) {
COLORREF infocolor = GetSysColor(COLOR_INFOBK);
SkColor background_color = SkColorSetRGB(GetRValue(infocolor),
diff --git a/chrome/browser/ui/views/options/options_group_view.h b/chrome/browser/ui/views/options/options_group_view.h
index 0d391b4..1d32c0a 100644
--- a/chrome/browser/ui/views/options/options_group_view.h
+++ b/chrome/browser/ui/views/options/options_group_view.h
@@ -36,7 +36,7 @@ class OptionsGroupView : public views::View {
protected:
// views::View overrides:
virtual AccessibilityTypes::Role GetAccessibleRole();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void ViewHierarchyChanged(bool is_add,
views::View* parent,
views::View* child);
diff --git a/chrome/browser/ui/views/sad_tab_view.cc b/chrome/browser/ui/views/sad_tab_view.cc
index a5d2838..aae9163 100644
--- a/chrome/browser/ui/views/sad_tab_view.cc
+++ b/chrome/browser/ui/views/sad_tab_view.cc
@@ -70,7 +70,7 @@ SadTabView::SadTabView(TabContents* tab_contents, Kind kind)
}
}
-void SadTabView::Paint(gfx::Canvas* canvas) {
+void SadTabView::OnPaint(gfx::Canvas* canvas) {
SkPaint paint;
SkSafeUnref(paint.setShader(
gfx::CreateGradientShader(
diff --git a/chrome/browser/ui/views/sad_tab_view.h b/chrome/browser/ui/views/sad_tab_view.h
index 284fedf..8694aa4 100644
--- a/chrome/browser/ui/views/sad_tab_view.h
+++ b/chrome/browser/ui/views/sad_tab_view.h
@@ -34,7 +34,7 @@ class SadTabView : public views::View,
virtual ~SadTabView() {}
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
// Overridden from views::LinkController:
diff --git a/chrome/browser/ui/views/status_bubble_views.cc b/chrome/browser/ui/views/status_bubble_views.cc
index 022ea11..0aea46b 100644
--- a/chrome/browser/ui/views/status_bubble_views.cc
+++ b/chrome/browser/ui/views/status_bubble_views.cc
@@ -151,7 +151,7 @@ class StatusBubbleViews::StatusView : public views::Label,
void AnimateToState(double state);
void AnimationEnded(const Animation* animation);
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
BubbleStage stage_;
BubbleStyle style_;
@@ -335,7 +335,7 @@ void StatusBubbleViews::StatusView::SetStyle(BubbleStyle style) {
}
}
-void StatusBubbleViews::StatusView::Paint(gfx::Canvas* canvas) {
+void StatusBubbleViews::StatusView::OnPaint(gfx::Canvas* canvas) {
SkPaint paint;
paint.setStyle(SkPaint::kFill_Style);
paint.setFlags(SkPaint::kAntiAlias_Flag);
diff --git a/chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc b/chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc
index 345482b..a3249fd 100644
--- a/chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc
+++ b/chrome/browser/ui/views/tab_contents/tab_contents_view_views.cc
@@ -230,7 +230,7 @@ void TabContentsViewViews::OnBoundsChanged() {
WasSized(size());
}
-void TabContentsViewViews::Paint(gfx::Canvas* canvas) {
+void TabContentsViewViews::OnPaint(gfx::Canvas* canvas) {
}
void TabContentsViewViews::UpdateDragCursor(WebDragOperation operation) {
diff --git a/chrome/browser/ui/views/tab_icon_view.cc b/chrome/browser/ui/views/tab_icon_view.cc
index 34f1270..6ec77da 100644
--- a/chrome/browser/ui/views/tab_icon_view.cc
+++ b/chrome/browser/ui/views/tab_icon_view.cc
@@ -132,7 +132,7 @@ void TabIconView::PaintIcon(gfx::Canvas* canvas,
dest_h, filter);
}
-void TabIconView::Paint(gfx::Canvas* canvas) {
+void TabIconView::OnPaint(gfx::Canvas* canvas) {
bool rendered = false;
if (throbber_running_) {
diff --git a/chrome/browser/ui/views/tab_icon_view.h b/chrome/browser/ui/views/tab_icon_view.h
index 2b83d29..90a5641 100644
--- a/chrome/browser/ui/views/tab_icon_view.h
+++ b/chrome/browser/ui/views/tab_icon_view.h
@@ -39,8 +39,8 @@ class TabIconView : public views::View {
// Set the throbber to the light style (for use on dark backgrounds).
void set_is_light(bool is_light) { is_light_ = is_light; }
- // Overriden from View
- virtual void Paint(gfx::Canvas* canvas);
+ // Overridden from View
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual gfx::Size GetPreferredSize();
private:
diff --git a/chrome/browser/ui/views/tabs/dragged_tab_controller.cc b/chrome/browser/ui/views/tabs/dragged_tab_controller.cc
index 0ee3832..f1345ad 100644
--- a/chrome/browser/ui/views/tabs/dragged_tab_controller.cc
+++ b/chrome/browser/ui/views/tabs/dragged_tab_controller.cc
@@ -80,7 +80,7 @@ class DockView : public views::View {
return gfx::Size(DockInfo::popup_width(), DockInfo::popup_height());
}
- virtual void PaintBackground(gfx::Canvas* canvas) {
+ virtual void OnPaintBackground(gfx::Canvas* canvas) {
SkRect outer_rect = { SkIntToScalar(0), SkIntToScalar(0),
SkIntToScalar(width()),
SkIntToScalar(height()) };
diff --git a/chrome/browser/ui/views/tabs/dragged_tab_view.cc b/chrome/browser/ui/views/tabs/dragged_tab_view.cc
index 367019e..0a08049 100644
--- a/chrome/browser/ui/views/tabs/dragged_tab_view.cc
+++ b/chrome/browser/ui/views/tabs/dragged_tab_view.cc
@@ -121,7 +121,7 @@ void DraggedTabView::Update() {
///////////////////////////////////////////////////////////////////////////////
// DraggedTabView, views::View overrides:
-void DraggedTabView::Paint(gfx::Canvas* canvas) {
+void DraggedTabView::OnPaint(gfx::Canvas* canvas) {
if (show_contents_on_drag_)
PaintDetachedView(canvas);
else
diff --git a/chrome/browser/ui/views/tabs/dragged_tab_view.h b/chrome/browser/ui/views/tabs/dragged_tab_view.h
index d2dda61..d404a31 100644
--- a/chrome/browser/ui/views/tabs/dragged_tab_view.h
+++ b/chrome/browser/ui/views/tabs/dragged_tab_view.h
@@ -52,7 +52,7 @@ class DraggedTabView : public views::View {
private:
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
virtual gfx::Size GetPreferredSize();
diff --git a/chrome/browser/ui/views/tabs/side_tab.cc b/chrome/browser/ui/views/tabs/side_tab.cc
index e29eeeb..89b0977 100644
--- a/chrome/browser/ui/views/tabs/side_tab.cc
+++ b/chrome/browser/ui/views/tabs/side_tab.cc
@@ -75,7 +75,7 @@ void SideTab::Layout() {
font_height());
}
-void SideTab::Paint(gfx::Canvas* canvas) {
+void SideTab::OnPaint(gfx::Canvas* canvas) {
if (ShouldPaintHighlight()) {
SkPaint paint;
paint.setColor(kTabBackgroundColor);
diff --git a/chrome/browser/ui/views/tabs/side_tab.h b/chrome/browser/ui/views/tabs/side_tab.h
index dde816b..540c45e 100644
--- a/chrome/browser/ui/views/tabs/side_tab.h
+++ b/chrome/browser/ui/views/tabs/side_tab.h
@@ -22,7 +22,7 @@ class SideTab : public BaseTab {
// views::View Overrides:
virtual void Layout();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual gfx::Size GetPreferredSize();
protected:
diff --git a/chrome/browser/ui/views/tabs/tab.h b/chrome/browser/ui/views/tabs/tab.h
index a5b6c98..debd280 100644
--- a/chrome/browser/ui/views/tabs/tab.h
+++ b/chrome/browser/ui/views/tabs/tab.h
@@ -63,7 +63,7 @@ class Tab : public BaseTab {
private:
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void Layout();
virtual void OnThemeChanged();
virtual std::string GetClassName() const { return kViewClassName; }
diff --git a/chrome/browser/ui/views/theme_install_bubble_view.cc b/chrome/browser/ui/views/theme_install_bubble_view.cc
index f28e848..067952f 100644
--- a/chrome/browser/ui/views/theme_install_bubble_view.cc
+++ b/chrome/browser/ui/views/theme_install_bubble_view.cc
@@ -112,7 +112,7 @@ void ThemeInstallBubbleView::Reposition() {
popup_->SetBounds(gfx::Rect(x, y, size.width(), size.height()));
}
-void ThemeInstallBubbleView::Paint(gfx::Canvas* canvas) {
+void ThemeInstallBubbleView::OnPaint(gfx::Canvas* canvas) {
SkScalar rad[8];
for (int i = 0; i < 8; ++i)
rad[i] = SkIntToScalar(kBubbleCornerRadius);
diff --git a/chrome/browser/ui/views/theme_install_bubble_view.h b/chrome/browser/ui/views/theme_install_bubble_view.h
index dc81616..450d4cf 100644
--- a/chrome/browser/ui/views/theme_install_bubble_view.h
+++ b/chrome/browser/ui/views/theme_install_bubble_view.h
@@ -56,7 +56,7 @@ class ThemeInstallBubbleView : public NotificationObserver,
// Shut down the popup and remove our notifications.
void Close();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
// The content area at the start of the animation.
gfx::Rect tab_contents_bounds_;
diff --git a/chrome/browser/ui/views/toolbar_view.cc b/chrome/browser/ui/views/toolbar_view.cc
index ee2813d..6e26bf2 100644
--- a/chrome/browser/ui/views/toolbar_view.cc
+++ b/chrome/browser/ui/views/toolbar_view.cc
@@ -509,7 +509,7 @@ void ToolbarView::Layout() {
bool maximized = browser_->window() && browser_->window()->IsMaximized();
if (!IsDisplayModeNormal()) {
int edge_width = maximized ?
- 0 : kPopupBackgroundEdge->width(); // See Paint().
+ 0 : kPopupBackgroundEdge->width(); // See OnPaint().
location_bar_->SetBounds(edge_width, PopupTopSpacing(),
width() - (edge_width * 2), location_bar_->GetPreferredSize().height());
return;
@@ -590,8 +590,8 @@ void ToolbarView::Layout() {
#endif
}
-void ToolbarView::Paint(gfx::Canvas* canvas) {
- View::Paint(canvas);
+void ToolbarView::OnPaint(gfx::Canvas* canvas) {
+ View::OnPaint(canvas);
if (IsDisplayModeNormal())
return;
diff --git a/chrome/browser/ui/views/toolbar_view.h b/chrome/browser/ui/views/toolbar_view.h
index f08e35f..37176e6 100644
--- a/chrome/browser/ui/views/toolbar_view.h
+++ b/chrome/browser/ui/views/toolbar_view.h
@@ -118,7 +118,7 @@ class ToolbarView : public AccessiblePaneView,
// Overridden from views::View:
virtual gfx::Size GetPreferredSize();
virtual void Layout();
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void OnThemeChanged();
// The apparent horizontal space between most items, and the vertical padding
diff --git a/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.h b/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.h
index b1af5e3..6440a1e 100644
--- a/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.h
+++ b/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.h
@@ -77,9 +77,9 @@ class AutocompletePopupContentsView : public views::View,
virtual void AnimationProgressed(const ui::Animation* animation);
// Overridden from views::View:
- virtual void Paint(gfx::Canvas* canvas);
+ virtual void OnPaint(gfx::Canvas* canvas);
virtual void PaintChildren(gfx::Canvas* canvas) {
// We paint our children inside Paint().
}
virtual void Layout();
virtual void OnMouseEntered(const views::MouseEvent& event);
@@ -77,9 +77,9 @@ class AutocompletePopupContentsView : public views::View,
virtual void PaintChildren(gfx::Canvas* canvas) {
- // We paint our children inside Paint().
+ // We paint our children inside OnPaint().
}
virtual void Layout();
diff --git a/chrome/browser/ui/views/tabs/tab.cc b/chrome/browser/ui/views/tabs/tab.cc
index 9cb04d9..56c268a 100644
--- a/chrome/browser/ui/views/tabs/tab.cc
+++ b/chrome/browser/ui/views/tabs/tab.cc
@@ -184,7 +184,7 @@ void Tab::DataChanged(const TabRendererData& old) {
////////////////////////////////////////////////////////////////////////////////
// Tab, views::View overrides:
-void Tab::Paint(gfx::Canvas* canvas) {
+void Tab::OnPaint(gfx::Canvas* canvas) {
// Don't paint if we're narrower than we can render correctly. (This should
// only happen during animations).
if (width() < GetMinimumUnselectedSize().width() && !data().mini)
@@ -298,8 +298,8 @@ void Tab::Layout() {
// Certain UI elements within the Tab (the favicon, etc.) are not represented
// as child Views (which is the preferred method). Instead, these UI elements
// are drawn directly on the canvas from within Tab::Paint(). The Tab's child
// Views (for example, the Tab's close button which is a views::Button
// instance) are automatically mirrored by the mirroring infrastructure in
// views. The elements Tab draws directly on the canvas need to be manually
// mirrored if the View's layout is right-to-left.
@@ -298,8 +298,8 @@ void Tab::Layout() {
// Certain UI elements within the Tab (the favicon, etc.) are not represented
// as child Views (which is the preferred method). Instead, these UI elements
- // are drawn directly on the canvas from within Tab::Paint(). The Tab's child
- // Views (for example, the Tab's close button which is a views::Button
+ // are drawn directly on the canvas from within Tab::OnPaint(). The Tab's
+ // child Views (for example, the Tab's close button which is a views::Button
// instance) are automatically mirrored by the mirroring infrastructure in
// views. The elements Tab draws directly on the canvas need to be manually